# SegTraQ

[![PyPI version](https://badge.fury.io/py/segtraq.svg)](https://badge.fury.io/py/segtraq)

SegTraQ - **Seg**mentation and **Tra**nscript Assignment **Q**uality Control - A Python toolkit for quantitative and visual quality control of segmentation and transcript assignment in spatial omics data.

* PyPI package: https://pypi.org/search/segtraq
* Free software: MIT License
* Documentation: https://lazdaria.github.io/SegTraQ

> ⚠️ Note: SegTraQ is under active development. 
> Features, interfaces, and functionality may change in upcoming releases.